@@ -34,8 +34,12 @@ int rcpp_import_to_trip_table (const char* bikedb,
 int rcpp_import_to_file_table (const char * bikedb,
         Rcpp::CharacterVector datafiles, std::string city, int nfiles);
 
+namespace db_add {
+
 HeaderStruct get_field_positions (const std::string fname,
         const std::string header_file_name, bool data_has_stations,
         const std::string city);
 void get_field_quotes (const std::string line, HeaderStruct &headers);
 void dump_headers (const HeaderStruct &headers);
+
+} // end namespace db_add
